Stan Math Library: stan::scalar_type< T * > Struct Template Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Types | List of all members
stan::scalar_type< T * > Struct Template Reference

`#include <scalar_type.hpp>`

## Public Types
typedef scalar_type< T >::type | type

## Detailed Description

### template<typename T>
struct stan::scalar_type< T * >

Definition at line 39 of file scalar_type.hpp.

## Member Typedef Documentation

template<typename T >

typedef scalar_type<T>::type stan::scalar_type< T * >::type

Definition at line 40 of file scalar_type.hpp.

The documentation for this struct was generated from the following file:

- stan/math/prim/scal/meta/scalar_type.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.